<?php
/**
 * @package    component.helper
 * @author     Pham Thanh Binh <binhpham@netq.vn>
 * @copyright  NetQ.,JSC (http://www.netqcreative.com)
 * @version    $Id$
 */
 
// No direct access
defined('_JEXEC') or die('Restricted access');

/**
 * This is album controller for component. It contain some methods to manage album
 *
 * @category   Controller
 * @author     Pham Thanh Binh <binhpham@netq.vn>
 */
class QGalleryControllerAlbums extends QController
{
	/**
	 * Display default page to list all albums
	 *
	 * @return void
	 */
	public function display ()
	{
		JRequest::setVar('layout', (JRequest::getVar('type') == 'social') ? 'social' : 'default');
		parent::display();
	}
	
	/**
	 * Action to display all pictures from albums
	 *
	 * @return void
	 */
	public function pictures ()
	{
		$albumId = JRequest::getInt('album');
		if ($albumId <= 0) {
			$this->setRedirect('index.php?option=com_qgallery&controller=albums', 'Invalid album ID', 'error');
			return;
		}
		
		parent::display();
	}
	
	/**
	 * Method to handling remove task. It will verify id of 
	 * album and remove it from database
	 *
	 * @return void
	 */
	public function remove ()
	{
		// Verify token before process request
		if (JRequest::checkToken())
		{
			try {
				// Retrieve selected album from request
				$cid = JRequest::getVar('cid');
				
				// Redirect to album list when error
				if (!is_array($cid)) {
					$this->setRedirect('index.php?option=com_qgallery&controller=albums', 'Invalid album ID');
					return;
				}
				
				$model = JModel::getInstance('Albums', 'QGalleryModel');
				list($deleted, $skipped) = $model->remove($cid);
				
				$message = sprintf("Total %d albums has been deleted and %d albums skipped (The album must be empty before delete)", $deleted, $skipped);
				$this->setRedirect('index.php?option=com_qgallery&controller=albums', $message);
			}
			catch (Exception $ex) {
				$this->setRedirect('index.php?option=com_qgallery&controller=albums', $ex->getMessage());
			}
		}
	}
	
	/**
	 * Use this method for handle add action, which is 
	 * responsible for checking the data, store data through Model
	 *
	 * @return void
	 */
	public function form ()
	{
		$task = JRequest::getVar('task');
		
		// Process form after it submitted back
		if (JRequest::checkToken() && ($task == 'save') || $task == 'apply')
		{
			try {
				// Save album information when client submitted
				$savedId = $this->model('Albums')->save(JRequest::get('post'));
				
				// Redirect page after saved data
				if ($task == 'apply') {
					$this->setRedirect("index.php?option=com_qgallery&controller=albums&task=edit&cid[]={$savedId}", 'Album information has been saved');
				}
				else {
					$this->setRedirect("index.php?option=com_qgallery&controller=albums", 'Album information has been saved');
				}
			}
			catch (Exception $ex) {
				JError::raiseWarning(null, $ex->getMessage());
			}
		}
		
		parent::display();
	}
	
	/**
	 * This action allow user to import albums from facebook
	 *
	 * @return void
	 */
	public function import ()
	{
		JRequest::setVar('tmpl', 'component');
		if (JRequest::checkToken() && JRequest::getVar('submit') == 'Continue')
		{
			try {
				JModel::getInstance('Albums', 'QGalleryModel')->import(JRequest::get('post'));
				JRequest::setVar('importCompleted', true);
			}
			catch (Exception $ex) {
				JRequest::setVar('message', $ex->getMessage());
			}
		}
		
		parent::display();
	}
	
	/**
	 * Action to change publish status of album to yes or no
	 *
	 * @return void
	 */
	public function publish ()
	{
		$cid = JRequest::getVar('cid');
		$task = JRequest::getVar('task');
		
		$table = JTable::getInstance('Albums', 'Table');
		$table->publish($cid, (($task == 'publish') ? 1 : 0));
		
		$message = sprintf('Total %d albums has been change status to %sed', count($cid), $task);
		$this->setRedirect('index.php?option=com_qgallery&controller=albums', $message);
	}
	
	/**
	 * Set default picture as cover of album
	 *
	 * @return void
	 */
	public function cover ()
	{
		$pictureId = JRequest::getInt('id');
		$albumId = JRequest::getInt('album');
		
		if ($albumId <= 0) {
			$message = 'Invalid album ID';
			$this->setRedirect('index.php?option=com_qgallery&controller=albums', $message);
			return;
		}
		
		if ($pictureId <= 0) {
			$message = 'Invalid picture ID';
			$this->setRedirect('index.php?option=com_qgallery&controller=albums&task=pictures&album='.$albumId, $message);
			return;
		}
		
		$album = JTable::getInstance('Albums', 'Table');
		$album->load($albumId);
		$album->cover_id = $pictureId;
		$album->store();
		
		$message = 'Album cover photo has been updated';
		$this->setRedirect('index.php?option=com_qgallery&controller=albums&task=pictures&album='.$albumId, $message);
		
		return;
	}
	
	/**
	 * Action to update ordering value for albums
	 *
	 * @return void
	 */
	public function saveOrder ()
	{
		try {
			$cid = JRequest::getVar('cid');
			$order = JRequest::getVar('order');
			
			$model = JModel::getInstance('Albums', 'QGalleryModel');
			$model->updateOrder($cid, $order);
			
			$message = sprintf('Total %d albums has been reorderd', count($cid));
			$this->setRedirect('index.php?option=com_qgallery&controller=albums', $message);
		}
		catch (Exception $ex) {
			$this->setRedirect('index.php?option=com_qgallery&controller=albums', $ex->getMessage());
		}
	}
}




