<?php
/**
 * @package Component Facebook Gallry for Joomla! 1.5
 * @version $Id: Model.php 599 2010-11-12 23:26:33Z trungdt $
 * @author NETQ CREATIVE SOFTWARE (service@netqcreative.com)
 * @copyright (C) 2010- NETQ CREATIVE SOLUTION
 * @license GNU/GPL http://www.gnu.org/copyleft/gpl.html
**/
 
// No direct access
defined('_JEXEC') or die('Restricted access');

/**
 * Model exception
 *
 * @category	Exception
 * @author    Pham Thanh Binh <binhpham@netq.vn>
 */
class QModelException extends Exception
{}

/**
 * This file is a part of QGallery project. 
 * It contain base model with some common methods
 *
 * @category	Model
 * @author    Pham Thanh Binh <binhpham@netq.vn>
 */
class QModel extends JModel
{
	// Variable to handle pagination instance
	protected $_paginate;
	
	// Store all fetched albums
	protected $_list;
	
	/**
	 * Constructor method
	 */
	public function __construct ()
	{
		parent::__construct();
		
		$app = JFactory::getApplication();
		
		$name = $this->getName();
			
		// Get pagination request variables
    	$limit = $app->getUserStateFromRequest($name.'.list.limit', 'limit', $app->getCfg('list_limit'), 'int');
    	$limitstart = JRequest::getVar('limitstart', 0, '', 'int');
    	
    	$filters = $app->getUserStateFromRequest($name.'.list.state', 'filters', array(), 'array');
    	$order = $app->getUserStateFromRequest($name.'.list.order', 'filter_order', '', 'cmd');
    	$orderDirection = $app->getUserStateFromRequest($name.'.list.order_dir', 'filter_order_Dir', 'ASC', 'word');
    	
    	$this->setState('order_by', $order);
    	$this->setState('order_direction', $orderDirection);
    	$this->setState('filters', $filters);
    	$this->setState('limit', $limit);
    	$this->setState('limitstart', $limitstart);
	}
	
	/**
	 * Get filter data determined by client
	 *
	 * @return array
	 */
	public function getFilters ()
	{
		return $this->getState('filters');
	}
	
	/**
	 * Retrieve ordering options
	 *
	 * @return array
	 */
	public function getOrderOptions ()
	{
		return array(
			'by' => $this->getState('order_by'), 
			'dir' => $this->getState('order_direction')
		);
	}
	
	/**
	 * Retrieve pagination object
	 *
	 * @return JPagination
	 */
	public function getPaginate ()
	{
		jimport('joomla.html.pagination');
		
		if (empty($this->_paginate)) {
			$this->_paginate = new JPagination($this->getTotal(), $this->getState('limitstart'), $this->getState('limit'));
		}
		
		return $this->_paginate;
	}
	
	/**
	 * Retrieve all albums from database
	 *
	 * @return array
	 */
	public function getList ()
	{
		if (empty($this->_list)) {
			$this->_loadList();
		}
		
		return $this->_list;
	}
	
	/**
	 * Retrieve total rows counted in database
	 *
	 * @return int
	 */
	public function getTotal ()
	{
		if (empty($this->_list)) {
			$this->_loadList();
		}
		
		$this->_db->setQuery('SELECT FOUND_ROWS()');
		return $this->_db->loadResult();
	}
	
	/**
	 * This method use for load album from database
	 *
	 * @return void
	 */
	protected function _loadList ()
	{
		$this->_list = $this->_getList($this->buildSQL(), $this->getState('limitstart'), $this->getState('limit'));
	}
}




