<?php
/**
 * @package Component Facebook Gallry for Joomla! 1.5
 * @version $Id: albums.php 599 2010-11-12 23:26:33Z trungdt $
 * @author NETQ CREATIVE SOFTWARE (service@netqcreative.com)
 * @copyright (C) 2010- NETQ CREATIVE SOLUTION
 * @license GNU/GPL http://www.gnu.org/copyleft/gpl.html
**/

// No direct access
defined('_JEXEC') or die('Restricted access');

/**
 * Album model
 *
 * @category	Model
 * @author		Pham Thanh Binh <binhpham@netq.vn>
 */
class QGalleryModelAlbums extends QModel
{
	/**
	 * Retrieve row by specified id
	 *
	 * @param int $id
	 * @return JTable
	 */
	public function getData ($id = null)
	{
		$table = JTable::getInstance('Albums', 'Table');
		$ids = JRequest::getVar('cid');
		
		if ($id === null && !empty($ids)) {
			$id = (is_array($ids)) ? array_shift($ids) : intval($ids);
		}
		
		if ($id > 0) {
			$table->load($id);
		}
		
		return $table;
	}
	
	/**
	 * Retrieve all album from database
	 *
	 * @return array
	 */
	public function getAll ()
	{
		$this->_db->setQuery("SELECT '' AS id, '-- Select Album --' AS name UNION SELECT id, name FROM #__sg_albums WHERE social_id=''");
		return $this->_db->loadObjectList();
	}
	
	/**
	 * Method to import picture from facebook to album
	 *
	 * @param array $params
	 * @return void
	 */
	public function import ($params)
	{
		if (!isset($params['aid']) || empty($params['aid'])) {
			throw new QModelException("You must select an album to import");
		}
		
		if (isset($params['destination']) && $params['destination'] == '1' && empty($params['album']['name'])) {
			throw new QModelException("Please enter name of the album you wish to create");
		}
		
		if (isset($params['destination']) && $params['destination'] == '0' && empty($params['album']['id'])) {
			throw new QModelException("Please select an album to import");
		}
		
		$aid = $params['aid'];
		$fbAlbum = FacebookHelper::getAlbumById($aid);
		
		if ($fbAlbum == null) {
			throw new QModelException("Selected album doesn't exist on Facebook");
		}
		
		$album = JTable::getInstance('Albums', 'Table');
		if ($params['destination'] == 0) {
			$album->load($params['album']['id']);
		}
		else {
			$album->name = $params['album']['name'];
			$album->published = 1;
		}
		
		$album->social_id = $fbAlbum['aid'];
		$album->social_name = $fbAlbum['name'];
		$album->size+= $fbAlbum['size'];
		
		if (!$album->store()) {
			throw new QModelException($album->getError());
		}
		
		return $this->importPictureToAlbum($fbAlbum, $album);
	}
	
	/**
	 * Check picture is existed in album by social ID
	 *
	 * @param string $id
	 * @param int $albumId
	 *
	 * @return bool
	 */
	public function pictureExist ($id, $albumId)
	{
		$this->_db->setQuery("SELECT COUNT(*) FROM #__sg_pictures WHERE social_id LIKE '{$id}' AND album_id={$albumId} LIMIT 1");
		return (0 < intval($this->_db->loadResult()));
	}
	
	/**
	 * Method to import picture to an album
	 *
	 * @param string $socialAlbum
	 * @param int $album
	 *
	 * @return void
	 */
	public function importPictureToAlbum ($socialAlbum, $album)
	{
		// Get all picture of album by id from facebook server
		$pictures = FacebookHelper::getPicturesFromAlbum($socialAlbum['aid']);
		
		// Loop to each picture and import it to destination album
		foreach ($pictures as $picture)
		{
			if ($this->pictureExist($picture['pid'], $album->id)) {
				continue;
			}
			
			$table = JTable::getInstance('Pictures', 'Table');
			$table->album_id = $album->id;
			$table->album_name = $album->name;
			$table->caption = $picture['caption'];
			$table->social_id = $picture['pid'];
			$table->src = $picture['src_big'];
			$table->src_small = $picture['src'];
			$table->published = 1;
			$table->ordering = $picture['position'];
			$table->created = $picture['created'];
			$table->store();
		}
		
		// Update pictures count for album
		$this->_db->setQuery("SELECT COUNT(*) FROM #__sg_pictures WHERE album_id={$album->id}");
		$album->size = $this->_db->loadResult();
		$album->store();
		
		return true;
	}
	
	/**
	 * Method to save data to table in database server
	 *
	 * @param mixed $params
	 * @return int
	 */
	public function save ($params)
	{
		foreach ($params['album'] as $key => $value) {
			if (is_array($value)) {
				$params['album'][$key] = serialize($value);
			}
		}
		
		$table = JTable::getInstance('Albums', 'Table');
		$table->load($params['album']['id']);
		$table->bind($params['album']);
		
		if (!$table->store()) {
			throw new Exception($table->getError());
		}
		
		if (!empty($table->social_id)) {
			$this->importPictureToAlbum($table->social_id, $table);
		}
		
		return $table->id;
	}
	
	/**
	 * Remove one or more album from database
	 *
	 * @param int $id
	 * @return void
	 */
	public function remove ($ids)
	{
		if (!is_array($ids)) {
			$ids = array($ids);
		}
		
		$table = JTable::getInstance('Albums', 'Table');
		$deleted = 0;
		$skipped = 0;

		foreach ($ids as $id)
		{
			if (!is_numeric($id)) {
				continue;
			}
			
			$table->load($id);
			($this->isEmpty($id) && $table->delete()) ? $deleted++ : $skipped++;
		}
		
		return array($deleted, $skipped);
	}
	
	/**
	 * Check album is empty
	 *
	 * @param int $albumId
	 * @return bool
	 */
	public function isEmpty ($albumId)
	{
		$this->_db->setQuery("SELECT COUNT(*) FROM #__sg_pictures WHERE album_id={$albumId} LIMIT 1");
		return (0 == intval($this->_db->loadResult()));
	}
	
	/**
	 * Update order position for albums
	 *
	 * @param array $cid
	 * @param array $order
	 */
	public function updateOrder ($cid, $orders)
	{
		if (!is_array($cid) || !is_array($orders) || count($cid) != count($orders)) {
			throw new Exception('Error when update album position');
		}
		
		foreach ($cid as $index => $id) {
			$order = $orders[$index];
			$this->_db->setQuery("UPDATE #__sg_albums SET ordering={$order} WHERE id={$id} LIMIT 1");
			$this->_db->query();
		}
		
		return true;
	}
	
	/**
	 * Helper method to generate SQL for fetching data
	 *
	 * @return string
	 */
	protected function buildSQL ()
	{
		$filters = $this->getState('filters');
		
		// Conditions use for filtering data
		$conditions = array();
		
		if (isset($filters['keyword']) && !empty($filters['keyword'])) {
			$search = array();
			$search[] = "name REGEXP '{$filters['keyword']}'";
			$search[] = "description REGEXP '{$filter['keyword']}'";
			
			$conditions[] = implode(' OR ', $search);
		}
		
		if (isset($filters['state']) && is_numeric($filters['state'])) {
			$conditions[] = "published={$filters['state']}";
		}
		
		$orderBy = $this->getState('order_by');
		$orderDir = $this->getState('order_direction');
		$ordering = '';
		
		if (!empty($orderBy)) {
			$ordering.= "ORDER BY {$orderBy}";
			if (!empty($orderDir)) {
				$ordering.= " {$orderDir}";
			}
		}
		
		$query = "
			SELECT SQL_CALC_FOUND_ROWS * 
			FROM #__sg_albums ".((!empty($conditions)) ? "
			WHERE ".implode(' AND ', $conditions) : '')." {$ordering}
		";
		
		// Return SQL
		return $query;
	}
}




